# README file for Portion 2

See the *Concatenated Results* README for more details.

## Portion Content Summary

The following is a summary of the Python scripts that were used in this directory. The summaries are based on the script docstrings.

| script | summary       |
| :----- | :------------ |
| File 1 | Description 1 |
| File 2 | Description 2 |
| File 3 | Description 3 |
| .      | .             |
| .      | .             |
| .      | .             |
| File n | Description n |

## Reproducing this portion

To reproduce the results in this portion, run the following scripts in the stated order:

- File 1
- File 1
- .
- .
- .
- File n

The results of this portion are then used as the input for the de-identification and concatenation suite.